@@ -575,13 +575,25 @@ class DarkCodeServer:
         """Start the Claude Code CLI process.
 
         SECURITY: Uses validated working directory from config.
+        Uses -p (print mode) with stream-json for bidirectional streaming.
         """
         try:
             # Use validated working directory
             working_dir = self.config.safe_working_dir
 
+            # Build command with streaming and permission handling
+            cmd = [
+                "claude",
+                "-p",  # Print mode for non-interactive streaming
+                "--output-format", "stream-json",
+                "--input-format", "stream-json",
+                "--verbose",  # Required for stream-json
+                "--include-partial-messages",  # Enable streaming deltas
+                "--permission-mode", self.config.permission_mode,
+            ]
+
             session.process = subprocess.Popen(
-                ["claude", "--output-format", "stream-json"],
+                cmd,
                 cwd=str(working_dir),
                 stdin=subprocess.PIPE,
                 stdout=subprocess.PIPE,
@@ -678,21 +690,82 @@ class DarkCodeServer:
         """Handle parsed output from Claude."""
         msg_type = msg.get("type", "")
 
-        if msg_type == "assistant":
-            content = msg.get("message", {}).get("content") or msg.get("content")
-            await session.websocket.send(json.dumps({
-                "type": "claude_message",
-                "role": "assistant",
-                "content": content,
-                "timestamp": int(time.time() * 1000),
-            }))
+        if msg_type == "stream_event":
+            # Handle streaming deltas for real-time text updates
+            event = msg.get("event", {})
+            event_type = event.get("type", "")
 
-            # Save assistant message to chat history
-            if session.chat_session_id and content:
-                self._chat_history.save_message(session.chat_session_id, {
+            if event_type == "content_block_delta":
+                delta = event.get("delta", {})
+                if delta.get("type") == "text_delta":
+                    text = delta.get("text", "")
+                    if text:
+                        await session.websocket.send(json.dumps({
+                            "type": "stream_delta",
+                            "text": text,
+                            "index": event.get("index", 0),
+                        }))
+
+            elif event_type == "content_block_start":
+                content_block = event.get("content_block", {})
+                await session.websocket.send(json.dumps({
+                    "type": "stream_start",
+                    "index": event.get("index", 0),
+                    "blockType": content_block.get("type", "text"),
+                }))
+
+            elif event_type == "content_block_stop":
+                await session.websocket.send(json.dumps({
+                    "type": "stream_stop",
+                    "index": event.get("index", 0),
+                }))
+
+            elif event_type == "message_start":
+                await session.websocket.send(json.dumps({
+                    "type": "message_start",
+                }))
+
+            elif event_type == "message_stop":
+                await session.websocket.send(json.dumps({
+                    "type": "message_stop",
+                }))
+
+        elif msg_type == "assistant":
+            # Extract text from Claude's content array structure
+            # Claude returns: {"message": {"content": [{"type": "text", "text": "..."}]}}
+            raw_content = msg.get("message", {}).get("content") or msg.get("content")
+
+            # Parse content array to extract text
+            if isinstance(raw_content, list):
+                # Content is array of blocks like [{"type": "text", "text": "..."}]
+                text_parts = []
+                for block in raw_content:
+                    if isinstance(block, dict):
+                        if block.get("type") == "text":
+                            text_parts.append(block.get("text", ""))
+                        elif block.get("type") == "tool_use":
+                            # Tool use blocks are handled separately
+                            pass
+                content = "\n".join(text_parts)
+            elif isinstance(raw_content, str):
+                content = raw_content
+            else:
+                content = str(raw_content) if raw_content else ""
+
+            if content:
+                await session.websocket.send(json.dumps({
+                    "type": "claude_message",
                     "role": "assistant",
                     "content": content,
-                })
+                    "timestamp": int(time.time() * 1000),
+                }))
+
+                # Save assistant message to chat history
+                if session.chat_session_id:
+                    self._chat_history.save_message(session.chat_session_id, {
+                        "role": "assistant",
+                        "content": content,
+                    })
 
         elif msg_type == "tool_use":
             await session.websocket.send(json.dumps({
@@ -715,11 +788,30 @@ class DarkCodeServer:
             await session.websocket.send(json.dumps({
                 "type": "status",
                 "status": "complete",
-                "cost": msg.get("cost_usd"),
+                "cost": msg.get("total_cost_usd") or msg.get("cost_usd"),
                 "duration": msg.get("duration_ms"),
+                "result": msg.get("result"),
             }))
 
+        elif msg_type == "system":
+            # System init message with session info
+            subtype = msg.get("subtype", "")
+            if subtype == "init":
+                await session.websocket.send(json.dumps({
+                    "type": "system_init",
+                    "sessionId": msg.get("session_id"),
+                    "model": msg.get("model"),
+                    "tools": msg.get("tools", []),
+                }))
+            else:
+                await session.websocket.send(json.dumps({
+                    "type": "system",
+                    "subtype": subtype,
+                    "data": msg,
+                }))
+
         else:
+            # Forward unknown message types
             await session.websocket.send(json.dumps({
                 "type": "claude_output",
                 "parsed": msg,
@@ -731,8 +823,13 @@ class DarkCodeServer:
             return False
         return session.process.poll() is None
 
-    async def _write_to_process(self, session: Session, text: str) -> bool:
-        """Write text to Claude process stdin with error handling.
+    async def _write_to_process(self, session: Session, text: str, is_json: bool = False) -> bool:
+        """Write to Claude process stdin with error handling.
+
+        Args:
+            session: The session with the Claude process
+            text: The text to write (user message content)
+            is_json: If True, text is already JSON-formatted; if False, wrap in user message
 
         Returns True if write succeeded, False otherwise.
         """
@@ -750,7 +847,20 @@ class DarkCodeServer:
             return False
 
         try:
-            session.process.stdin.write(text + "\n")
+            # Format as stream-json input if not already JSON
+            if is_json:
+                data = text
+            else:
+                # Wrap in Claude's expected stream-json input format
+                data = json.dumps({
+                    "type": "user",
+                    "message": {
+                        "role": "user",
+                        "content": text
+                    }
+                })
+
+            session.process.stdin.write(data + "\n")
             session.process.stdin.flush()
             return True
         except BrokenPipeError:
